#include "map.h"

Map::Map()
{
	for(int j = 0; j < 5; j++)
	  {
		  for(int i = 0; i < 11; i++)
		  {
			int color;
			switch(rand()%4)
			{
				case 0:
					color = 0;
					break;
				case 1:
					color = 1;
					break;
				case 2:
					color = 2;
					break;
				case 3:
					color = 3;
					break;
				default:break;
			}
			Tiles[j*11 + i] = new Tile(i*80 + 40, j*80 + 140, color);
		  }
	  }

	LastPropogation = 0;
	explode_sound = -1;
	MovementRate = 0.1;
	bomb_explode_count = 0;
	elapsed_time = 0;
	update = false;
	exploded = false;
}

void Map::Reset()
{
		for(int j = 0; j < 5; j++)
	  {
		  for(int i = 0; i < 11; i++)
		  {
			int color;
			switch(rand()%4)
			{
				case 0:
					color = 0;
					break;
				case 1:
					color = 1;
					break;
				case 2:
					color = 2;
					break;
				case 3:
					color = 3;
					break;
				default:break;
			}
			Tiles[j*11 + i] = new Tile(i*80 + 40, j*80 + 140, color);
		  }
	  }

	LastPropogation = 0;
	explode_sound = -1;
	MovementRate = 0.1;
	bomb_explode_count = 0;
	elapsed_time = 0;
	update = false;
	exploded = false;
}

void Map::Draw(HGE *hgep)
{
	for(int j = 0; j < 5; j++)
	{
		  for(int i = 0; i < 11; i++)
		  {
			  Tiles[j*11 + i]->Draw(hgep);
		  }
	}
	for(int j = 0; j < 5; j++)
	{
		  for(int i = 0; i < 11; i++)
		  {
			  Tiles[j*11 + i]->DrawExploding(hgep);
		  }
	}
}

void Map::LoadSounds(FMOD::System *system)
{
	system->createSound("reaction sfx-01.wav", FMOD_DEFAULT, 0, &sound0);
	system->createSound("reaction sfx-02.wav", FMOD_DEFAULT, 0, &sound1);
	system->createSound("reaction sfx-03.wav", FMOD_DEFAULT, 0, &sound2);
	system->createSound("reaction sfx-04.wav", FMOD_DEFAULT, 0, &sound3);
	system->createSound("reaction sfx-05.wav", FMOD_DEFAULT, 0, &sound4);
	system->createSound("reaction sfx-06.wav", FMOD_DEFAULT, 0, &sound5);
	system->createSound("reaction sfx-07.wav", FMOD_DEFAULT, 0, &sound6);
	system->createSound("reaction sfx-08.wav", FMOD_DEFAULT, 0, &sound7);
	system->createSound("reaction sfx-09.wav", FMOD_DEFAULT, 0, &sound8);
	system->createSound("reaction sfx-10.wav", FMOD_DEFAULT, 0, &sound9);
	system->createSound("reaction sfx-11.wav", FMOD_DEFAULT, 0, &sound10);
}

void Map::PlaySounds(FMOD::System *system, FMOD::Channel *channel)
{
	switch(explode_sound)
	{
	case -1:
		break;
	case 0:
		system->playSound(FMOD_CHANNEL_FREE, sound0, false, &channel);
		break;
	case 1:
		system->playSound(FMOD_CHANNEL_FREE, sound1, false, &channel);
		break;
	case 2:
		system->playSound(FMOD_CHANNEL_FREE, sound2, false, &channel);
		break;
	case 3:
		system->playSound(FMOD_CHANNEL_FREE, sound3, false, &channel);
		break;
	case 4:
		system->playSound(FMOD_CHANNEL_FREE, sound4, false, &channel);
		break;
	case 5:
		system->playSound(FMOD_CHANNEL_FREE, sound5, false, &channel);
		break;
	case 6:
		system->playSound(FMOD_CHANNEL_FREE, sound6, false, &channel);
		break;
	case 7:
		system->playSound(FMOD_CHANNEL_FREE, sound7, false, &channel);
		break;
	case 8:
		system->playSound(FMOD_CHANNEL_FREE, sound8, false, &channel);
		break;
	case 9:
		system->playSound(FMOD_CHANNEL_FREE, sound9, false, &channel);
		break;
	case 10:
		system->playSound(FMOD_CHANNEL_FREE, sound10, false, &channel);
		break;
	default:break;
	}

	explode_sound = -1;
}

void Map::Update(float dt,FMOD::System *system, FMOD::Channel *channel)
{	
	elapsed_time += dt;
	MovementRate = ((float)elapsed_time/240000.0)*0.15 + 0.1;
	if(update == true)
	{
		for(int j = 0; j < 5; j++)
			{
				for(int i = 0; i < 11; i++)
				{
					Tiles[j*11+i]->RegenOn();
				}
		}

	}
	else
	{
		for(int j = 0; j < 5; j++)
			{
				for(int i = 0; i < 11; i++)
				{
					Tiles[j*11+i]->RegenOff();
				}
		}

	}

	UpdateTiles(dt);
	if(update == true)
	{
		Propogate(dt);
		Move(dt);
		PlaySounds(system, channel);
	}
}

void Map::Move(float dt)
{
	bool shifted = false;
	for(int k = 0; k < 55; k++)
	{
		if(Tiles[k]->GetHorizontalPos() <= -40 && shifted == false)
		{
			for(int j = 0; j < 5; j++)
			{
				for(int i = 0; i < 11; i++)
				{
					if(i == 10)
					{
						if(j == 0)
							Tiles[j*11 + i]->Reinitialize(Tiles[j*11 + i-1]->GetHorizontalPos()+80,-1,Tiles[(j+1)*11 + i]->GetColor(),Tiles[j*11 + i-1]->GetColor(),-1);
						else if(j == 4)
							Tiles[j*11 + i]->Reinitialize(Tiles[j*11 + i-1]->GetHorizontalPos()+80,Tiles[(j-1)*11 + i]->GetColor(),-1,Tiles[j*11 + i-1]->GetColor(),-1);
						else
							Tiles[j*11 + i]->Reinitialize(Tiles[j*11 + i-1]->GetHorizontalPos()+80,Tiles[(j-1)*11 + i]->GetColor(),Tiles[(j+1)*11 + i]->GetColor(),Tiles[j*11 + i-1]->GetColor(),-1);
						
						Tiles[j*11+i]->SetPlayerStatus(false);	
		
					}
					else
					{
						Tiles[j*11 + i]->SetHorizontalPos(Tiles[j*11 + i+1]->GetHorizontalPos());
						Tiles[j*11 + i]->SetColor(Tiles[j*11 + i + 1]->GetColor());
						Tiles[j*11 + i]->SetState(Tiles[j*11 + i + 1]->GetState());
						Tiles[j*11 + i]->SetAlpha(Tiles[j*11 + i + 1]->GetAlpha());
						Tiles[j*11 + i]->SetScale(Tiles[j*11 + i + 1]->GetScale());
						Tiles[j*11 + i]->SetPlayerStatus(Tiles[j*11 + i + 1]->GetPlayerStatus());
						Tiles[j*11 + i]->SetBombTime(Tiles[j*11 + i+1]->GetBombTime());
						Tiles[j*11 + i]->SetElapsedTime(Tiles[j*11 + i+1]->GetElapsedTime());
					}
				}	
			}	
			shifted = true;
		}
	}

	for(int k = 0; k < 55; k++)
	{
		Tiles[k]->MoveLeft(MovementRate*dt);
	}
	
}

void Map::Propogate(float dt)
{
	explode_sound = -1;
	LastPropogation += dt;
	//explode stuff

	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetHorizontalPos() <= 40)
			{
				if(Tiles[j*11 + i]->GetState() != EXPLODING && Tiles[j*11 + i]->GetState() != RESPAWNING && Tiles[j*11 + i]->GetState() != BOMBEXPLODING)
				{
					if(Tiles[j*11 + i]->GetState() == BOMB || Tiles[j*11 + i]->GetState() == ACTIVEBOMB || Tiles[j*11 + i]->GetState() == BOMBEXPLODENEXT)  
					{
						Tiles[j*11 + i]->SetState(BOMBEXPLODING);
						explode_sound = 0;
					}
					else
					{
						Tiles[j*11 + i]->SetState(EXPLODING);
						explode_sound = 0;
					}
				}
			}
		}
	}

	
	BombTest();


	//check time since last propogation
	//if its time to, then propogate

	if(LastPropogation >= 150)
	{
		for(int j = 0; j < 5; j++)
		{
			for(int i = 1; i < 11; i++)
			{
				if(Tiles[j*11 + i]->GetState() == EXPLODENEXT)
				{
					Tiles[j*11 + i]->SetState(EXPLODING);
					if(i > explode_sound)
						explode_sound = i;
				}
				if(Tiles[j*11 + i]->GetState() == BOMBEXPLODENEXT)
				{
					Tiles[j*11 + i]->SetState(BOMBEXPLODING);
					if(i > explode_sound)
						explode_sound = i;
				}
			}
		}


		for(int j = 0; j < 5; j++)
		{
			for(int i = 1; i < 11; i++)
			{
				if(j == 0)
				{
					if(i == 10)
					{
						if(	(Tiles[j*11 + i-1]->GetState() == EXPLODING && Tiles[j*11 + i-1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j+1)*11 + i]->GetState() == EXPLODING && Tiles[(j+1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor()))
						{
							if(Tiles[j*11 + i]->GetState() != EXPLODING && Tiles[j*11 + i]->GetState() != RESPAWNING && Tiles[j*11 + i]->GetState() != BOMBEXPLODING)
							{
								if(Tiles[j*11 + i]->GetState() == NORMAL)
									Tiles[j*11 + i]->SetState(EXPLODENEXT);
								else
									Tiles[j*11 + i]->SetState(BOMBEXPLODENEXT);
							}
						}
					}
					else
					{
						if((Tiles[j*11 + i+1]->GetState() == EXPLODING && Tiles[j*11 + i+1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[j*11 + i-1]->GetState() == EXPLODING && Tiles[j*11 + i-1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j+1)*11 + i]->GetState() == EXPLODING && Tiles[(j+1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor()))
						{
							if(Tiles[j*11 + i]->GetState() != EXPLODING && Tiles[j*11 + i]->GetState() != RESPAWNING && Tiles[j*11 + i]->GetState() != BOMBEXPLODING)
							{
								if(Tiles[j*11 + i]->GetState() == NORMAL)
									Tiles[j*11 + i]->SetState(EXPLODENEXT);
								else
									Tiles[j*11 + i]->SetState(BOMBEXPLODENEXT);
							}
						}
					}
				}
				if(j == 4)
				{
					if(i == 10)
					{
						if(	(Tiles[j*11 + i-1]->GetState() == EXPLODING && Tiles[j*11 + i-1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j-1)*11 + i]->GetState() == EXPLODING && Tiles[(j-1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor()))
						{
							if(Tiles[j*11 + i]->GetState() != EXPLODING && Tiles[j*11 + i]->GetState() != RESPAWNING && Tiles[j*11 + i]->GetState() != BOMBEXPLODING)
							{
								if(Tiles[j*11 + i]->GetState() == NORMAL)
									Tiles[j*11 + i]->SetState(EXPLODENEXT);
								else
									Tiles[j*11 + i]->SetState(BOMBEXPLODENEXT);
							}
						}
					}
					else
					{
						if((Tiles[j*11 + i+1]->GetState() == EXPLODING && Tiles[j*11 + i+1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[j*11 + i-1]->GetState() == EXPLODING && Tiles[j*11 + i-1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j-1)*11 + i]->GetState() == EXPLODING && Tiles[(j-1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor()))
						{
							if(Tiles[j*11 + i]->GetState() != EXPLODING && Tiles[j*11 + i]->GetState() != RESPAWNING && Tiles[j*11 + i]->GetState() != BOMBEXPLODING)
							{
								if(Tiles[j*11 + i]->GetState() == NORMAL)
									Tiles[j*11 + i]->SetState(EXPLODENEXT);
								else
									Tiles[j*11 + i]->SetState(BOMBEXPLODENEXT);
							}
						}
					}
				}
				if(j != 0 && j != 4)
				{
					if(i == 10)
					{
						if(	(Tiles[j*11 + i-1]->GetState() == EXPLODING && Tiles[j*11 + i-1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j+1)*11 + i]->GetState() == EXPLODING && Tiles[(j+1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j-1)*11 + i]->GetState() == EXPLODING && Tiles[(j-1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor()))
						{
							if(Tiles[j*11 + i]->GetState() != EXPLODING && Tiles[j*11 + i]->GetState() != RESPAWNING && Tiles[j*11 + i]->GetState() != BOMBEXPLODING)
							{
								if(Tiles[j*11 + i]->GetState() == NORMAL)
									Tiles[j*11 + i]->SetState(EXPLODENEXT);
								else
									Tiles[j*11 + i]->SetState(BOMBEXPLODENEXT);
							}
						}
					}
					else
					{
						if((Tiles[j*11 + i+1]->GetState() == EXPLODING && Tiles[j*11 + i+1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[j*11 + i-1]->GetState() == EXPLODING && Tiles[j*11 + i-1]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j+1)*11 + i]->GetState() == EXPLODING && Tiles[(j+1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor())||
							(Tiles[(j-1)*11 + i]->GetState() == EXPLODING && Tiles[(j-1)*11 + i]->GetColor() == Tiles[j*11 + i]->GetColor()))
						{
							if(Tiles[j*11 + i]->GetState() != EXPLODING && Tiles[j*11 + i]->GetState() != RESPAWNING && Tiles[j*11 + i]->GetState() != BOMBEXPLODING)
							{
								if(Tiles[j*11 + i]->GetState() == NORMAL)
									Tiles[j*11 + i]->SetState(EXPLODENEXT);
								else
									Tiles[j*11 + i]->SetState(BOMBEXPLODENEXT);
							}
						}
					}
				}
			}
		}

		BombExplode();
		LastPropogation = 0;
	}
}

void Map::UpdateTiles(float dt)
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			Tiles[j*11 + i]->Update(dt);
		}
	}
}

void Map::AddPlayer(int pi, int pj)
{
	if(pi > 10)
		pi = 10;
	if(pi < 1)
		pi = 1;
	if(pj > 4)
		pj = 4;
	if(pj < 0)
		pj = 4;

	Tiles[pj*11 + pi]->SetPlayerStatus(true);
	
}

float Map::GetPlayerX()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true)
				return Tiles[j*11 + i]->GetHorizontalPos();
		}
	}
}

float Map::GetPlayerY()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true)
				return Tiles[j*11 + i]->GetVerticalPos();
		}
	}
}

float Map::GetTempX()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true)
			{
				if(j != 4)
					return Tiles[(j+1)*11 + i]->GetHorizontalPos();
				else
					return Tiles[(j)*11 + i]->GetHorizontalPos();
			}
				
		}
	}
}

float Map::GetTempY()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
		if(Tiles[j*11 + i]->GetPlayerStatus() == true)
			{
				if(j != 4)
					return Tiles[(j+1)*11 + i]->GetVerticalPos();
				else
					return Tiles[(j)*11 + i]->GetVerticalPos();
			}
		}
	}
}

void Map::MovePlayerRight(void)
{
	bool found = false;

	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true && found == false)
			{
				if(i == 10)
					found = true;
				else
				{
					Tiles[j*11 + i]->SetPlayerStatus(false);
					Tiles[j*11 + i+1]->SetPlayerStatus(true);
					found = true;
				}
			}
		}
	}
}

void Map::MovePlayerLeft(void)
{
	bool found = false;

	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true && found == false)
			{
				if(i == 0)
					found = true;
				else
				{
					Tiles[j*11 + i]->SetPlayerStatus(false);
					Tiles[j*11 + i-1]->SetPlayerStatus(true);
					found = true;
				}
			}
		}
	}
}

void Map::MovePlayerUp(void)
{
	bool found = false;

	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true && found == false)
			{
				if(j == 0)
					found = true;
				else
				{
					Tiles[j*11 + i]->SetPlayerStatus(false);
					Tiles[(j-1)*11 + i]->SetPlayerStatus(true);
					found = true;
				}
			}
		}
	}
}

void Map::MovePlayerDown(void)
{
	bool found = false;

	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true && found == false)
			{
				if(j == 4)
					found = true;
				else
				{
					Tiles[j*11 + i]->SetPlayerStatus(false);
					Tiles[(j+1)*11 + i]->SetPlayerStatus(true);
					found = true;
				}
			}
		}
	}
}

int Map::GetPlayerTileState()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetPlayerStatus() == true)
			{
				return Tiles[j*11 + i]->GetState();
			}

		}
	}
}

void Map::ExplodeAll()
{
	if(exploded == false)
	{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			Tiles[j*11+i]->SetState(EXPLODING);
		}
	}
	}
	exploded = true;
}

int Map::GetPlayerCount()
{
	int count = 0;
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11+i]->GetPlayerStatus() == true)
				count++;
		}
	}
	return count;
}

void Map::BombTest()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{	
			if(Tiles[j*11 + i]->GetState() == BOMBEXPLODING)
			{
				if(i == 0)
				{
					if(j == 0)
					{
						if(Tiles[j*11 + i+1]->GetState() == BOMB || Tiles[j*11 + i+1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i+1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i+1]->SetState(BOMBEXPLODENEXT);
						}
						else if(Tiles[j*11 + i+1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i+1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i+1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j+1)*11 + i]->GetState() == BOMB || Tiles[(j+1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j+1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j+1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j+1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j+1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
					else if(j == 4)
					{
						if(Tiles[j*11 + i+1]->GetState() == BOMB || Tiles[j*11 + i+1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i+1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i+1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i+1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i+1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i+1]->SetState(EXPLODENEXT);
						}


						///////////////////////////////////////////

						if(Tiles[(j-1)*11 + i]->GetState() == BOMB || Tiles[(j-1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j-1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j-1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j-1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j-1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
					else
					{
						if(Tiles[j*11 + i+1]->GetState() == BOMB || Tiles[j*11 + i+1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i+1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i+1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i+1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i+1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i+1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j-1)*11 + i]->GetState() == BOMB || Tiles[(j-1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j-1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j-1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j-1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j-1)*11 + i]->SetState(EXPLODENEXT);
						}
						///////////////////////////////////////////

						if(Tiles[(j+1)*11 + i]->GetState() == BOMB || Tiles[(j+1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j+1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j+1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j+1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j+1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
				}
				else if(i == 10)
				{
					if(j == 0)
					{


						if(Tiles[j*11 + i-1]->GetState() == BOMB || Tiles[j*11 + i-1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i-1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i-1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i-1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i-1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i-1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j+1)*11 + i]->GetState() == BOMB || Tiles[(j+1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j+1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i+1]->GetState() == NORMAL)
						{
							if(Tiles[(j+1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j+1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
					else if(j == 4)
					{

						if(Tiles[j*11 + i-1]->GetState() == BOMB || Tiles[j*11 + i-1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i-1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i-1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i-1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i-1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i-1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j-1)*11 + i]->GetState() == BOMB || Tiles[(j-1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j-1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j-1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j-1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j-1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
					else
					{

						if(Tiles[j*11 + i-1]->GetState() == BOMB || Tiles[j*11 + i-1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i-1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i-1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i-1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i-1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i-1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j-1)*11 + i]->GetState() == BOMB || Tiles[(j-1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j-1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j-1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j-1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j-1)*11 + i]->SetState(EXPLODENEXT);
						}
						///////////////////////////////////////////

						if(Tiles[(j+1)*11 + i]->GetState() == BOMB || Tiles[(j+1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j+1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j+1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j+1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j+1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
				}
				else
				{
					if(j == 0)
					{
						if(Tiles[j*11 + i+1]->GetState() == BOMB || Tiles[j*11 + i+1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i+1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i+1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i+1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i+1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i+1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[j*11 + i-1]->GetState() == BOMB || Tiles[j*11 + i-1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i-1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i-1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i-1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i-1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i-1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j+1)*11 + i]->GetState() == BOMB || Tiles[(j+1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j+1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j+1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j+1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j+1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
					else if(j == 4)
					{
						if(Tiles[j*11 + i+1]->GetState() == BOMB || Tiles[j*11 + i+1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i+1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i+1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i+1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i+1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i+1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[j*11 + i-1]->GetState() == BOMB || Tiles[j*11 + i-1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i-1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i-1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i-1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i-1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i-1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j-1)*11 + i]->GetState() == BOMB || Tiles[(j-1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j-1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j-1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j-1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j-1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
					else
					{
						if(Tiles[j*11 + i+1]->GetState() == BOMB || Tiles[j*11 + i+1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i+1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i+1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i+1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i+1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i+1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[j*11 + i-1]->GetState() == BOMB || Tiles[j*11 + i-1]->GetState() == ACTIVEBOMB || Tiles[j*11 + i-1]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[j*11 + i-1]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[j*11 + i-1]->GetState() == NORMAL)
						{
							if(Tiles[j*11 + i-1]->GetState() != BOMBEXPLODING)
								Tiles[j*11 + i-1]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////

						if(Tiles[(j-1)*11 + i]->GetState() == BOMB || Tiles[(j-1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j-1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j-1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j-1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j-1)*11 + i]->SetState(EXPLODENEXT);
						}
						///////////////////////////////////////////

						if(Tiles[(j+1)*11 + i]->GetState() == BOMB || Tiles[(j+1)*11 + i]->GetState() == ACTIVEBOMB || Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODENEXT)  
						{
							Tiles[(j+1)*11 + i]->SetState(BOMBEXPLODENEXT);
							bomb_explode_count++;
						}
						else if(Tiles[(j+1)*11 + i]->GetState() == NORMAL)
						{
							if(Tiles[(j+1)*11 + i]->GetState() != BOMBEXPLODING)
								Tiles[(j+1)*11 + i]->SetState(EXPLODENEXT);
						}

						///////////////////////////////////////////
					}
				}
			}
		}
	}
}


void Map::BombExplode()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11 + i]->GetState() == BOMB || Tiles[j*11 + i]->GetState() == ACTIVEBOMB)
			{
				if(i == 0)
				{
					if(j == 0)
					{
						if((Tiles[j*11 + i+1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i+1]->GetState() == EXPLODING)||
							(Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j+1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
					else if(j == 4)
					{
						if((Tiles[j*11 + i+1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i+1]->GetState() == EXPLODING)||
							(Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j-1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
					else
					{
						if((Tiles[j*11 + i+1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i+1]->GetState() == EXPLODING)||
							(Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j+1)*11 + i]->GetState() == EXPLODING)||
							(Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j-1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
				}
				else if(i == 10)
				{
					if(j == 0)
					{
						if((Tiles[j*11 + i-1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i-1]->GetState() == EXPLODING)||
							(Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j+1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
					else if(j == 4)
					{
						if((Tiles[j*11 + i-1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i-1]->GetState() == EXPLODING)||
							(Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j-1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
					else
					{
						if((Tiles[j*11 + i-1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i-1]->GetState() == EXPLODING)||
							(Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j+1)*11 + i]->GetState() == EXPLODING)||
							(Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j-1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
				}
				else
				{
					if(j == 0)
					{
						if((Tiles[j*11 + i+1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i+1]->GetState() == EXPLODING)||
							(Tiles[j*11 + i-1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i-1]->GetState() == EXPLODING)||
							(Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j+1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
					else if(j == 4)
					{
						if((Tiles[j*11 + i+1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i+1]->GetState() == EXPLODING)||
							(Tiles[j*11 + i-1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i-1]->GetState() == EXPLODING)||
							(Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j-1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
					else
					{
						if((Tiles[j*11 + i+1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i+1]->GetState() == EXPLODING)||
							(Tiles[j*11 + i-1]->GetState() == BOMBEXPLODING || Tiles[j*11 + i-1]->GetState() == EXPLODING)||
							(Tiles[(j+1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j+1)*11 + i]->GetState() == EXPLODING)||
							(Tiles[(j-1)*11 + i]->GetState() == BOMBEXPLODING || Tiles[(j-1)*11 + i]->GetState() == EXPLODING))
						{
							Tiles[j*11+i]->SetState(BOMBEXPLODENEXT);
						}
					}
				}


			}
		}
	}
}

void Map::DetonateBomb()
{
	for(int j = 0; j < 5; j++)
	{
		for(int i = 0; i < 11; i++)
		{
			if(Tiles[j*11+i]->GetPlayerStatus() == true)
			{
				for(int ti = i-1; ti <= i + 1; ti++)
				{
					for(int tj = j-1; tj <= j+1; tj++)
					{
						if((ti >= 0 && ti <= 10) && (tj >= 0 && tj <= 4))
						{
							if(Tiles[tj*11+ti]->GetState() == NORMAL || Tiles[tj*11+ti]->GetState() == EXPLODENEXT || Tiles[tj*11+ti]->GetState() == BOMB || Tiles[tj*11+ti]->GetState() == ACTIVEBOMB || Tiles[tj*11+ti]->GetState() == BOMBEXPLODENEXT)
							{
								if(!(tj == j && ti == i))
									Tiles[tj*11+ti]->Reset();
							}
						}
					}
				}
			}
		}
	}
}