#include "tile.h"



Tile::Tile(void)
{
	x = 80;
	y = 100;
	color = 0xFFFF0000;
	quad.blend = 2;
	quad.tex = 0;
	TileState = NORMAL;
	hasPlayer = false;
	elapsed_time = 0.0;
	elapsed_time2 = 0.0;
	bomb_time = 0.0;
	piece_gen_percent = 400;
	bomb_percent = 990;
	active_bomb_percent = 999;
}

Tile::Tile(float nx, float ny, int ncolor)
{
	x = nx;
	y = ny;
	color_number = ncolor;
	if(color_number == 0)
		color = 0xFF3068BF;
	if(color_number == 1)
		color = 0xFFA3B3CC;
	if(color_number == 2)
		color = 0xFF405980;
	if(color_number == 3)
		color = 0xFF5678AC;
	quad.blend = 2;
	quad.tex = 0;
	TileState = NORMAL;
	dt = 0;
	elapsed_time = 0.0;
	elapsed_time2 = 0.0;
	bomb_time = 0.0;
	alpha = 255.0;
	scale = 1.0;
	hasPlayer = false;
	piece_gen_percent = 400;
	bomb_percent = 990;
	active_bomb_percent = 999;
}

void Tile::Draw(HGE *hgep)
{
	quad.v[0].x = x - 40.05;
	quad.v[0].y = y - 40.05;
	quad.v[0].z = 1;
	quad.v[0].col = color;

	quad.v[1].x = x - 40.05;
	quad.v[1].y = y + 40.05;
	quad.v[1].z = 1;
	quad.v[1].col = color;

	quad.v[2].x = x + 40.05;
	quad.v[2].y = y + 40.05;
	quad.v[2].z = 1;
	quad.v[2].col = color;

	quad.v[3].x = x + 40.05;
	quad.v[3].y = y - 40.05;
	quad.v[3].z = 1;
	quad.v[3].col = color;

	if(TileState != EXPLODING && TileState != RESPAWNING && TileState != ACTIVEBOMB)
		hgep->Gfx_RenderQuad(&quad);

	if(TileState == RESPAWNING)
	{	
		if(color_number == 3)
			color = hgeColor(86.0/255.0,120.0/255.0,172.0/255.0,alpha/255.0).GetHWColor();
		if(color_number == 2)
			color = hgeColor(64.0/255.0,89.0/255.0,128.0/255.0,alpha/255.0).GetHWColor();
		if(color_number == 1)
			color = hgeColor(163.0/255.0,179.0/255.0,204.0/255.0,alpha/255.0).GetHWColor();
		if(color_number == 0)
			color = hgeColor(48.0/255.0,104.0/255.0,191.0/255.0,alpha/255.0).GetHWColor();
		
		quad.v[0].x = x - scale*40.05;
		quad.v[0].y = y - scale*40.05;
		quad.v[0].z = 0;
		quad.v[0].col = color;

		quad.v[1].x = x - scale*40.05;
		quad.v[1].y = y + scale*40.05;
		quad.v[1].z = 0;
		quad.v[1].col = color;

		quad.v[2].x = x + scale*40.05;
		quad.v[2].y = y + scale*40.05;
		quad.v[2].z = 0;
		quad.v[2].col = color;

		quad.v[3].x = x + scale*40.05;
		quad.v[3].y = y - scale*40.05;
		quad.v[3].z = 0;
		quad.v[3].col = color;

		hgep->Gfx_RenderQuad(&quad);
	}

	if(TileState == ACTIVEBOMB)
	{	
		alpha = (sin((bomb_time/1500.0)*6.28318531)/10.0 + 0.90)*255.0;

		if(TileState == ACTIVEBOMB)
			color = hgeColor(179.0/255.0,60.0/255.0,0.0/255.0,alpha/255.0).GetHWColor();


		quad.v[0].x = x - 40.05;
		quad.v[0].y = y - 40.05;
		quad.v[0].z = 1;
		quad.v[0].col = color;

		quad.v[1].x = x - 40.05;
		quad.v[1].y = y + 40.05;
		quad.v[1].z = 1;
		quad.v[1].col = color;

		quad.v[2].x = x + 40.05;
		quad.v[2].y = y + 40.05;
		quad.v[2].z = 1;
		quad.v[2].col = color;

		quad.v[3].x = x + 40.05;
		quad.v[3].y = y - 40.05;
		quad.v[3].z = 1;
		quad.v[3].col = color;

		hgep->Gfx_RenderQuad(&quad);
	}

}

void Tile::DrawExploding(HGE *hgep)
{
	if(TileState == EXPLODING || TileState == BOMBEXPLODING)
	{		
		if(color_number == 3)
			color = hgeColor(86.0/255.0,120.0/255.0,172.0/255.0,alpha/255.0).GetHWColor();
		if(color_number == 2)
			color = hgeColor(64.0/255.0,89.0/255.0,128.0/255.0,alpha/255.0).GetHWColor();
		if(color_number == 1)
			color = hgeColor(163.0/255.0,179.0/255.0,204.0/255.0,alpha/255.0).GetHWColor();
		if(color_number == 0)
			color = hgeColor(48.0/255.0,104.0/255.0,191.0/255.0,alpha/255.0).GetHWColor();

		if(color_number == 4)
			color = hgeColor(179.0/255.0,60.0/255.0,0.0/255.0,alpha/255.0).GetHWColor();
		if(color_number == 5)
			color = hgeColor(179.0/255.0,60.0/255.0,0.0/255.0,alpha/255.0).GetHWColor();
		
		quad.v[0].x = x - scale*40.05;
		quad.v[0].y = y - scale*40.05;
		quad.v[0].z = 0;
		quad.v[0].col = color;

		quad.v[1].x = x - scale*40.05;
		quad.v[1].y = y + scale*40.05;
		quad.v[1].z = 0;
		quad.v[1].col = color;

		quad.v[2].x = x + scale*40.05;
		quad.v[2].y = y + scale*40.05;
		quad.v[2].z = 0;
		quad.v[2].col = color;

		quad.v[3].x = x + scale*40.05;
		quad.v[3].y = y - scale*40.05;
		quad.v[3].z = 0;
		quad.v[3].col = color;

		hgep->Gfx_RenderQuad(&quad);
	}
}

void Tile::MoveLeft(float amount)
{
	x -= amount;
}

float Tile::GetHorizontalPos()
{
	return x;
}

void Tile::SetHorizontalPos(float nx)
{
	x = nx;
}

void Tile::Reinitialize(float nx,int up, int down, int left, int right)
{
	x = nx;
	int number = -1;
	int number2 = -1;
	int max = 0;

	int zero_total = 0;
	int one_total = 0;
	int two_total = 0;
	int three_total = 0;

	if(up == 0)
		zero_total++;
	if(down == 0)
		zero_total++;
	if(left == 0)
		zero_total++;
	if(right == 0)
		zero_total++;

	if(up == 1)
		one_total++;
	if(down == 1)
		one_total++;
	if(left == 1)
		one_total++;
	if(right == 1)
		one_total++;

	if(up == 2)
		two_total++;
	if(down == 2)
		two_total++;
	if(left == 2)
		two_total++;
	if(right == 2)
		two_total++;

	if(up == 3)
		three_total++;
	if(down == 3)
		three_total++;
	if(left == 3)
		three_total++;
	if(right == 3)
		three_total++;

	

	if(zero_total > max)
	{
		max = zero_total;
		number = 0;
	}
	if(one_total > max)
	{
		max = one_total;
		number = 1;
	}
	if(two_total > max)
	{
		max = two_total;
		number = 2;
	}
	if(three_total > max)
	{
		max = three_total;
		number = 3;
	}

	if(zero_total == one_total && zero_total == two_total && zero_total == three_total)
		number = rand() % 4;
	
	

		if(rand()%1000 > piece_gen_percent)
			number2 = rand() % 4;
		else
			number2 = number;
	


	switch(number2)
	{
	case 0:
		color = 0xFF3068BF;
		color_number = 0;
		break;
	case 1:
		color = 0xFFA3B3CC;
		color_number = 1;
		break;
	case 2:
		color = 0xFF405980;
		color_number = 2;
		break;
	case 3:
		color = 0xFF5678AC;
		color_number = 3;
		break;
	default:break;
	}
	
	TileState = NORMAL;

	if(rand() % 1000 > active_bomb_percent)
	{
		color = hgeColor(179.0/255.0,60.0/255.0,0.0/255.0,alpha/255.0).GetHWColor();
		color_number = 4;
		TileState = ACTIVEBOMB;
	}

	if(rand() % 1000 > bomb_percent)
	{
		color = hgeColor(179.0/255.0,60.0/255.0,0.0/255.0,alpha/255.0).GetHWColor();
		color_number = 5;
		TileState = BOMB;
	}

	bomb_time = 0.0;
	
}	

void Tile::SetColor(int ncolor)
{
	color_number = ncolor;
	if(color_number == 0)
		color = 0xFF3068BF;
	if(color_number == 1)
		color = 0xFFA3B3CC;
	if(color_number == 2)
		color = 0xFF405980;
	if(color_number == 3)
		color = 0xFF5678AC;

	if(color_number == 4)
		color = hgeColor(179.0/255.0,60.0/255.0,0.0/255.0,alpha/255.0).GetHWColor();;
	if(color_number == 5)
		color = hgeColor(179.0/255.0,60.0/255.0,0.0/255.0,alpha/255.0).GetHWColor();;
}

void Tile::Update(float ndt)
{
	dt = ndt;
	bomb_time += dt;
	elapsed_time2 += dt;
	
	piece_gen_percent = (elapsed_time2/480000.0)*400.0 + 400.0;
	if(piece_gen_percent > 800.0)
		piece_gen_percent = 800.0;

	bomb_percent = 1000 - ((elapsed_time2/180000.0)*40.0 + 10.0);
	if(bomb_percent < 950.0)
		bomb_percent = 950.0;

	active_bomb_percent = 1000 - (elapsed_time2/360000.0)*60.0;
	if(active_bomb_percent < 940.0)
		active_bomb_percent = 940.0;

	if(TileState == NORMAL)
	{
		scale = 1.0;
		alpha = 255.0;
	}
	if(TileState == EXPLODING || TileState == BOMBEXPLODING)
	{
		elapsed_time += dt;
		scale += dt/300.0;
		if(scale > 3.0)
			scale = 3.0;
		alpha = (1.0 - scale/3.0)*255.0;
	}

	if(TileState == RESPAWNING)
	{
		scale += dt/500.0;
		if(scale > 1.0)
		{
			scale = 1.0;
			alpha = 255.0;
			TileState = NORMAL;
		}
		
		
	}

	if(TileState == ACTIVEBOMB)
	{
		if(bomb_time > 3000)
			TileState = BOMBEXPLODING;
		
		
	}


	if(regen == true)
	{
	if(elapsed_time > 500.0)
	{
		TileState = RESPAWNING;
		elapsed_time = 0.0;
		scale = 0.0;
		alpha = 255.0;

	int rnum = color_number;
	while(rnum == color_number)
	{
		rnum = rand() % 4;
	}

	color_number = rnum;


	if(color_number == 0)
		color = 0xFF3068BF;
	if(color_number == 1)
		color = 0xFFA3B3CC;
	if(color_number == 2)
		color = 0xFF405980;
	if(color_number == 3)
		color = 0xFF5678AC;
	}
	}
}

void Tile::Reset()
{
	int rnum = color_number;
	while(rnum == color_number)
	{
		rnum = rand() % 4;
	}

	color_number = rnum;


	if(color_number == 0)
		color = 0xFF3068BF;
	if(color_number == 1)
		color = 0xFFA3B3CC;
	if(color_number == 2)
		color = 0xFF405980;
	if(color_number == 3)
		color = 0xFF5678AC;

	TileState = RESPAWNING;
		elapsed_time = 0.0;
		scale = 0.0;
		alpha = 255.0;
}